==> cxf-rt-frontend-jaxrs-2.6.2-sources.jar: org/apache/cxf/jaxrs/model/ProviderInfo.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.jaxrs.model;

import org.apache.cxf.Bus;

public class ProviderInfo<T> extends AbstractResourceInfo {

    private T provider;
    
    public ProviderInfo(T provider, Bus bus) {
        super(provider.getClass(), provider.getClass(), true, bus);
        this.provider = provider;
    }
    
    @Override
    public boolean isSingleton() {
        return true;
    }

    public T getProvider() {
        return provider;
    }
    
    public boolean equals(Object obj) {
        if (!(obj instanceof ProviderInfo)) {
            return false;
        }
        return provider.equals(((ProviderInfo<?>)obj).getProvider());
    }

    public int hashCode() {
        return provider.hashCode();
    }

}

==> cxf-rt-frontend-jaxrs-2.7.18-sources.jar: org/apache/cxf/jaxrs/model/ProviderInfo.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.jaxrs.model;

import org.apache.cxf.Bus;

public class ProviderInfo<T> extends AbstractResourceInfo {

    private T provider;
    
    public ProviderInfo(T provider, Bus bus) {
        super(provider.getClass(), provider.getClass(), true, true, bus, provider);
        this.provider = provider;
    }
    
    @Override
    public boolean isSingleton() {
        return true;
    }

    public T getProvider() {
        return provider;
    }
    
    public boolean equals(Object obj) {
        if (!(obj instanceof ProviderInfo)) {
            return false;
        }
        return provider.equals(((ProviderInfo<?>)obj).getProvider());
    }

    public int hashCode() {
        return provider.hashCode();
    }

}
